#!/usr/bin/python

# This file is part of the Web Browser Manager program.
#
# Copyright 2016 Zorin OS Technologies Ltd.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 3, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
# more details.

import gi, os
import listbox, widgets
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk, Gio

class WebBrowserManager(Gtk.Window):

    def __init__(self):
        Gtk.Window.__init__(self)
        self.set_resizable(False)
        self.set_size_request(750, 485)
        self.set_position(Gtk.WindowPosition.CENTER)

        icon = Gio.ThemedIcon(name="web-browser-manager")
        theme_icon = Gtk.IconTheme.get_default().lookup_by_gicon(icon, 48, 0)
        image = Gtk.Image.new_from_gicon(icon, Gtk.IconSize.DIALOG)
        if theme_icon:
            self.set_default_icon(theme_icon.load_icon())

        hb = Gtk.HeaderBar()
        hb.set_show_close_button(True)
        hb.props.title = "Web Browser Manager"
        self.set_titlebar(hb)

        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6,
                                   margin_start=70, margin_end=70, margin_left=70,
                                   margin_right=70, margin_top=4, margin_bottom=4,
                                   border_width=18)
        vbox.add(Browsers(self))
        self.add(vbox)

        self.show()

class Browsers(Gtk.Frame):
    def __init__(self, main_window):
        Gtk.Frame.__init__(self)

        self.browsers_box = Gtk.ListBox()
        self.browsers_box.set_selection_mode(Gtk.SelectionMode.NONE)
        self.browsers_box.set_header_func(listbox.list_box_update_header_func, None)

        self.browsers_box.add(widgets.BrowserRow("Chromium", "chromium-browser", "chromium-browser", main_window))
        self.browsers_box.add(widgets.BrowserRow("Firefox", "firefox", "firefox", main_window))
        self.browsers_box.add(widgets.BrowserRow("Falkon", "falkon", "falkon", main_window))
        self.browsers_box.add(widgets.BrowserRow("Web(Epiphany)", "epiphany-browser", "epiphany-browser", main_window))
        self.browsers_box.add(widgets.BrowserRow("Midori", "midori", "midori", main_window))
        self.browsers_box.add(widgets.BrowserRow("NetSurf", "netsurf", "netsurf", main_window))
        self.browsers_box.add(widgets.BrowserRow("QupZilla", "qupzilla", "qupzilla", main_window))

        self.add(self.browsers_box)

def main():
    window = WebBrowserManager()
    window.set_title("Web Browser Manager")
    window.connect("delete-event", Gtk.main_quit)
    window.show_all()
    Gtk.main()

if __name__ == "__main__": main()
